/**
 * Instrumentation hooks exposed by this module.
 */
export interface FetchWithJwtNetworkInstrumentation {
    /**
     * Used to send logs to Splunk
     */
    log(message: string): void;
    /**
     * Used to record an error, which will also be sent to Splunk, but also could be used
     * for sending error counts to Argus
     */
    error(err: Error | string): void;
}
export declare const instrumentation: FetchWithJwtNetworkInstrumentation;
/**
 * Allows external modules (typically a runtime environment) to set
 * instrumentation hooks for this module. Note that the hooks are
 * incremental - hooks not suppiled in newInstrumentation will retain
 * their previous values. The default instrumentation hooks are no-ops.
 *
 * @param newInstrumentation instrumentation hooks to be overridden
 */
export declare function instrument(newInstrumentation: Partial<FetchWithJwtNetworkInstrumentation>): void;
